FloatMargin

Trait FloatMargin 

pub trait FloatMargin: Copy + Default {
    type F;
    type I;

    // Required methods
    fn zero() -> Self;
    fn epsilon(self, epsilon: Self::F) -> Self;
    fn ulps(self, ulps: Self::I) -> Self;
}
A margin specifying a maximum distance two floating point values can be while still being considered equal enough.

Required Associated Types

type F

A floating-point type used for epsilon values

type I

An integer type used for ulps values

Required Methods

fn zero() -> Self

Zero margin

fn epsilon(self, epsilon: Self::F) -> Self

Set the epsilon value for this margin

fn ulps(self, ulps: Self::I) -> Self

Set the ulps value for this margin

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors